@@ -8,8 +8,8 @@
 ;; Keywords: http comm tools
 ;; URL: https://github.com/emacsorphanage/restclient
 ;; Package-Requires: ((emacs "26.1") (compat "30.1.0.0"))
-;; Package-Version: 20251021.1041
-;; Package-Revision: 426507f8f702
+;; Package-Version: 20251209.2022
+;; Package-Revision: 1800a4e367c2
 
 ;; This file is not part of GNU Emacs.
 ;; This file is public domain software. Do what you want.
@@ -977,6 +977,37 @@ point as arguments, with ARGS included as the final argument."
                            body-arg)))
       (message "curl command copied to clipboard."))))
 
+(declare-function edit-indirect-region "ext:edit-indirect")
+
+(defun restclient-edit-indirect-guess-mode (_parent-buffer _beg _end)
+  "Alternative to `edit-indirect-default-guess-mode'.
+Customize `edit-indirect-guess-mode-function' to name this function
+to get JSON request bodies editable in your preferred json mode."
+  ;; FIXME: Ideally, this should check the content-type of the
+  ;; current request.  Could use restclient-http-parse-current-and-do,
+  ;; but would need to stop request hook setup.
+  (save-excursion
+    (goto-char (point-min))
+    (if (looking-at "[[{]" t)
+       (funcall (restclient--preferred-mode "application/json"))
+     (normal-mode))))
+
+(defun restclient-indirect-edit ()
+  "Use `edit-indirect-region' to edit the request body in a separate buffer."
+  (interactive)
+  (if (not (fboundp 'edit-indirect-region))
+      (message "edit-indirect is not installed")
+    (save-excursion
+      (goto-char (restclient-current-min))
+      (when (re-search-forward restclient-method-url-regexp (point-max) t)
+        (forward-line)
+        (while (cond
+                ((and (looking-at restclient-header-regexp) (not (looking-at restclient-empty-line-regexp))))
+                ((looking-at restclient-use-var-regexp)))
+          (forward-line))
+        (when (looking-at restclient-empty-line-regexp)
+          (forward-line))
+        (edit-indirect-region (min (point) (restclient-current-max)) (restclient-current-max) t)))))
 
 (defun restclient-elisp-result-function (_args offset)
   "This is a hook constructor function.
@@ -1241,6 +1272,7 @@ Hide/show only happens if point is on the first line of a request."
     (define-key map (kbd "C-c C-i") 'restclient-show-info)
     (define-key map (kbd "C-c C-e") 'restclient-set-env)
     (define-key map (kbd "C-c M-e") 'restclient-reload-current-env)
+    (define-key map (kbd "C-c '") 'restclient-indirect-edit)
     map)
   "Keymap for `restclient-mode'.")
 
